# tanjun.dependencies

Default dependency utilities used within Tanjun and their abstract interfaces.

::: tanjun.dependencies.async_cache
    options:
        show_root_heading: true

::: tanjun.dependencies.callbacks
    options:
        show_root_heading: true

::: tanjun.dependencies.data
    options:
        show_root_heading: true

::: tanjun.dependencies.limiters
    options:
        show_root_heading: true

::: tanjun.dependencies.locales
    options:
        show_root_heading: true

::: tanjun.dependencies.owners
    options:
        show_root_heading: true

::: tanjun.dependencies.reloaders
    options:
        show_root_heading: true
